@@ -296,7 +296,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::, signals => {
     ),
   ];
 
-our $VERSION = '2.12.1';
+our $VERSION = '2.12.2';
 
 my ( $d_sane, $logger );
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
@@ -980,7 +980,10 @@ sub SET_PROPERTY {
                     'changed-paper' => sub {
                         $self->signal_handler_disconnect($signal);
                         my $paper = defined $newval ? $newval : __('Manual');
-                        $self->{combobp}->set_active_by_text($paper);
+                        my $retval =
+                          $self->{combobp}->set_active_by_text($paper);
+                        $logger->debug(
+                            "Widget update to $paper returned $retval");
                         if ( defined $logger ) {
                             $logger->debug("Finished$msg");
                         }
