@@ -15,7 +15,7 @@ use Locale::Language;
 use Readonly;
 Readonly our $DPI_OPTION_POS => 3;
 
-our $VERSION = '2.12.1';
+our $VERSION = '2.12.2';
 my $EMPTY = q{};
 my $COMMA = q{,};
 
@@ -85,9 +85,9 @@ sub setup {
 sub languages {
     if ( not %languages ) {
         my @codes;
-        my ( undef, $out, $err ) =
+        my ( undef, $out ) =
           Gscan2pdf::Document::exec_command( [ 'tesseract', '--list-langs' ] );
-        @codes = split /\n/xsm, $err ? $err : $out;
+        @codes = split /\n/xsm, $out;
         if ( $codes[0] =~ /^List[ ]of[ ]available[ ]languages/xsm ) {
             shift @codes;
         }
